--------------------------------------------------------------------------------
-- bram_wrapper.vhd
--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;

-- synthesis translate_off
LIBRARY UNISIM;
USE UNISIM.VCOMPONENTS.ALL;
-- synthesis translate_on

LIBRARY bram_block_v1_00_a;
USE bram_block_v1_00_a.ALL;

ENTITY bram_wrapper IS
PORT (
	-- instance bram
	BRAM_Rst_A : IN STD_LOGIC;
	BRAM_Clk_A : IN STD_LOGIC;
	BRAM_EN_A : IN STD_LOGIC;
	BRAM_WEN_A : IN STD_LOGIC_VECTOR(0 TO 3);
	BRAM_Addr_A : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Din_A : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Dout_A : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Rst_B : IN STD_LOGIC;
	BRAM_Clk_B : IN STD_LOGIC;
	BRAM_EN_B : IN STD_LOGIC;
	BRAM_WEN_B : IN STD_LOGIC_VECTOR(0 TO 3);
	BRAM_Addr_B : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Din_B : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Dout_B : IN STD_LOGIC_VECTOR(0 TO 31));
END bram_wrapper;

ARCHITECTURE IMP OF bram_wrapper IS

--------------------------------------------------------------------------------
COMPONENT bram_elaborate IS
GENERIC (
	C_MEMSIZE : INTEGER := 8192;
	C_PORT_DWIDTH : INTEGER := 32;
	C_PORT_AWIDTH : INTEGER := 32;
	C_NUM_WE : INTEGER := 4;
	C_FAMILY : STRING := "spartan2e");
PORT (
	BRAM_Rst_A : IN STD_LOGIC;
	BRAM_Clk_A : IN STD_LOGIC;
	BRAM_EN_A : IN STD_LOGIC;
	BRAM_WEN_A : IN STD_LOGIC_VECTOR(0 TO C_NUM_WE-1);
	BRAM_Addr_A : IN STD_LOGIC_VECTOR(0 TO C_PORT_AWIDTH-1);
	BRAM_Din_A : OUT STD_LOGIC_VECTOR(0 TO C_PORT_DWIDTH-1);
	BRAM_Dout_A : IN STD_LOGIC_VECTOR(0 TO C_PORT_DWIDTH-1);
	BRAM_Rst_B : IN STD_LOGIC;
	BRAM_Clk_B : IN STD_LOGIC;
	BRAM_EN_B : IN STD_LOGIC;
	BRAM_WEN_B : IN STD_LOGIC_VECTOR(0 TO C_NUM_WE-1);
	BRAM_Addr_B : IN STD_LOGIC_VECTOR(0 TO C_PORT_AWIDTH-1);
	BRAM_Din_B : OUT STD_LOGIC_VECTOR(0 TO C_PORT_DWIDTH-1);
	BRAM_Dout_B : IN STD_LOGIC_VECTOR(0 TO C_PORT_DWIDTH-1));
END COMPONENT;

--------------------------------------------------------------------------------
-- internal signals
--------------------------------------------------------------------------------

BEGIN

--------------------------------------------------------------------------------
-- Power assignments
--------------------------------------------------------------------------------
-- Constant assignments
--------------------------------------------------------------------------------
-- Top-level port assignments
--------------------------------------------------------------------------------
-- Lower-level assignments

--------------------------------------------------------------------------------
bram_block_0_i : bram_elaborate
GENERIC MAP (
	C_MEMSIZE => 8192,
	C_PORT_DWIDTH => 32,
	C_PORT_AWIDTH => 32,
	C_NUM_WE => 4,
	C_FAMILY => "spartan2e")
PORT MAP (
	BRAM_Rst_A => BRAM_Rst_A,
	BRAM_Clk_A => BRAM_Clk_A,
	BRAM_EN_A => BRAM_EN_A,
	BRAM_WEN_A => BRAM_WEN_A,
	BRAM_Addr_A => BRAM_Addr_A,
	BRAM_Din_A => BRAM_Din_A,
	BRAM_Dout_A => BRAM_Dout_A,
	BRAM_Rst_B => BRAM_Rst_B,
	BRAM_Clk_B => BRAM_Clk_B,
	BRAM_EN_B => BRAM_EN_B,
	BRAM_WEN_B => BRAM_WEN_B,
	BRAM_Addr_B => BRAM_Addr_B,
	BRAM_Din_B => BRAM_Din_B,
	BRAM_Dout_B => BRAM_Dout_B);

END ARCHITECTURE IMP;
