--------------------------------------------------------------------------------
-- myopb_bus_wrapper.vhd
--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;

-- synthesis translate_off
LIBRARY UNISIM;
USE UNISIM.VCOMPONENTS.ALL;
-- synthesis translate_on

LIBRARY opb_v20_v1_10_a;
USE opb_v20_v1_10_a.ALL;

ENTITY myopb_bus_wrapper IS
PORT (
	-- instance myopb_bus
	OPB_Clk : IN STD_LOGIC;
	SYS_Rst : IN STD_LOGIC;
	OPB_Rst : OUT STD_LOGIC;
	Debug_SYS_Rst : IN STD_LOGIC;
	WDT_Rst : IN STD_LOGIC;
	M_ABus : IN STD_LOGIC_VECTOR(0 TO 63);
	M_BE : IN STD_LOGIC_VECTOR(0 TO 7);
	M_beXfer : IN STD_LOGIC_VECTOR(0 TO 1);
	M_busLock : IN STD_LOGIC_VECTOR(0 TO 1);
	M_DBus : IN STD_LOGIC_VECTOR(0 TO 63);
	M_DBusEn : IN STD_LOGIC_VECTOR(0 TO 1);
	M_DBusEn32_63 : IN STD_LOGIC_VECTOR(0 TO 1);
	M_dwXfer : IN STD_LOGIC_VECTOR(0 TO 1);
	M_fwXfer : IN STD_LOGIC_VECTOR(0 TO 1);
	M_hwXfer : IN STD_LOGIC_VECTOR(0 TO 1);
	M_request : IN STD_LOGIC_VECTOR(0 TO 1);
	M_RNW : IN STD_LOGIC_VECTOR(0 TO 1);
	M_select : IN STD_LOGIC_VECTOR(0 TO 1);
	M_seqAddr : IN STD_LOGIC_VECTOR(0 TO 1);
	Sl_beAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_DBus : IN STD_LOGIC_VECTOR(0 TO 95);
	Sl_DBusEn : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_DBusEn32_63 : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_errAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_dwAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_fwAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_hwAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_retry : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_toutSup : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_xferAck : IN STD_LOGIC_VECTOR(0 TO 2);
	OPB_MRequest : OUT STD_LOGIC_VECTOR(0 TO 1);
	OPB_ABus : OUT STD_LOGIC_VECTOR(0 TO 31);
	OPB_BE : OUT STD_LOGIC_VECTOR(0 TO 3);
	OPB_beXfer : OUT STD_LOGIC;
	OPB_beAck : OUT STD_LOGIC;
	OPB_busLock : OUT STD_LOGIC;
	OPB_rdDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	OPB_wrDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	OPB_DBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	OPB_errAck : OUT STD_LOGIC;
	OPB_dwAck : OUT STD_LOGIC;
	OPB_dwXfer : OUT STD_LOGIC;
	OPB_fwAck : OUT STD_LOGIC;
	OPB_fwXfer : OUT STD_LOGIC;
	OPB_hwAck : OUT STD_LOGIC;
	OPB_hwXfer : OUT STD_LOGIC;
	OPB_MGrant : OUT STD_LOGIC_VECTOR(0 TO 1);
	OPB_pendReq : OUT STD_LOGIC_VECTOR(0 TO 1);
	OPB_retry : OUT STD_LOGIC;
	OPB_RNW : OUT STD_LOGIC;
	OPB_select : OUT STD_LOGIC;
	OPB_seqAddr : OUT STD_LOGIC;
	OPB_timeout : OUT STD_LOGIC;
	OPB_toutSup : OUT STD_LOGIC;
	OPB_xferAck : OUT STD_LOGIC);
END myopb_bus_wrapper;

ARCHITECTURE IMP OF myopb_bus_wrapper IS

--------------------------------------------------------------------------------
COMPONENT opb_v20 IS
GENERIC (
	C_BASEADDR : STD_LOGIC_VECTOR := X"0fff1000";
	C_HIGHADDR : STD_LOGIC_VECTOR := X"0fff10ff";
	C_OPB_AWIDTH : INTEGER := 32;
	C_OPB_DWIDTH : INTEGER := 32;
	C_NUM_MASTERS : INTEGER := 2;
	C_NUM_SLAVES : INTEGER := 3;
	C_USE_LUT_OR : INTEGER := 1;
	C_EXT_RESET_HIGH : INTEGER := 1;
	C_DYNAM_PRIORITY : INTEGER := 0;
	C_PARK : INTEGER := 0;
	C_PROC_INTRFCE : INTEGER := 0;
	C_REG_GRANTS : INTEGER := 0;
	C_DEV_BLK_ID : INTEGER := 0;
	C_DEV_MIR_ENABLE : INTEGER := 0);
PORT (
	OPB_Clk : IN STD_LOGIC;
	SYS_Rst : IN STD_LOGIC;
	OPB_Rst : OUT STD_LOGIC;
	Debug_SYS_Rst : IN STD_LOGIC;
	WDT_Rst : IN STD_LOGIC;
	M_ABus : IN STD_LOGIC_VECTOR(0 TO (C_OPB_AWIDTH*C_NUM_MASTERS)-1);
	M_BE : IN STD_LOGIC_VECTOR(0 TO (C_OPB_DWIDTH+7)/8*C_NUM_MASTERS-1);
	M_beXfer : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_busLock : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_DBus : IN STD_LOGIC_VECTOR(0 TO (C_OPB_DWIDTH*C_NUM_MASTERS)-1);
	M_DBusEn : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_DBusEn32_63 : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_dwXfer : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_fwXfer : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_hwXfer : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_request : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_RNW : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_select : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	M_seqAddr : IN STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	Sl_beAck : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_DBus : IN STD_LOGIC_VECTOR(0 TO (C_OPB_DWIDTH*C_NUM_SLAVES)-1);
	Sl_DBusEn : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_DBusEn32_63 : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_errAck : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_dwAck : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_fwAck : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_hwAck : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_retry : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_toutSup : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	Sl_xferAck : IN STD_LOGIC_VECTOR(0 TO C_NUM_SLAVES-1);
	OPB_MRequest : OUT STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	OPB_ABus : OUT STD_LOGIC_VECTOR(0 TO C_OPB_AWIDTH-1);
	OPB_BE : OUT STD_LOGIC_VECTOR(0 TO (C_OPB_DWIDTH+7)/8-1);
	OPB_beXfer : OUT STD_LOGIC;
	OPB_beAck : OUT STD_LOGIC;
	OPB_busLock : OUT STD_LOGIC;
	OPB_rdDBus : OUT STD_LOGIC_VECTOR(0 TO C_OPB_DWIDTH-1);
	OPB_wrDBus : OUT STD_LOGIC_VECTOR(0 TO C_OPB_DWIDTH-1);
	OPB_DBus : OUT STD_LOGIC_VECTOR(0 TO C_OPB_DWIDTH-1);
	OPB_errAck : OUT STD_LOGIC;
	OPB_dwAck : OUT STD_LOGIC;
	OPB_dwXfer : OUT STD_LOGIC;
	OPB_fwAck : OUT STD_LOGIC;
	OPB_fwXfer : OUT STD_LOGIC;
	OPB_hwAck : OUT STD_LOGIC;
	OPB_hwXfer : OUT STD_LOGIC;
	OPB_MGrant : OUT STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	OPB_pendReq : OUT STD_LOGIC_VECTOR(0 TO C_NUM_MASTERS-1);
	OPB_retry : OUT STD_LOGIC;
	OPB_RNW : OUT STD_LOGIC;
	OPB_select : OUT STD_LOGIC;
	OPB_seqAddr : OUT STD_LOGIC;
	OPB_timeout : OUT STD_LOGIC;
	OPB_toutSup : OUT STD_LOGIC;
	OPB_xferAck : OUT STD_LOGIC);
END COMPONENT;

--------------------------------------------------------------------------------
-- internal signals
--------------------------------------------------------------------------------

BEGIN

--------------------------------------------------------------------------------
-- Power assignments
--------------------------------------------------------------------------------
-- Constant assignments
--------------------------------------------------------------------------------
-- Top-level port assignments
--------------------------------------------------------------------------------
-- Lower-level assignments

--------------------------------------------------------------------------------
opb_v20_0_i : opb_v20
GENERIC MAP (
	C_BASEADDR => X"0fff1000",
	C_HIGHADDR => X"0fff10ff",
	C_OPB_AWIDTH => 32,
	C_OPB_DWIDTH => 32,
	C_NUM_MASTERS => 2,
	C_NUM_SLAVES => 3,
	C_USE_LUT_OR => 1,
	C_EXT_RESET_HIGH => 1,
	C_DYNAM_PRIORITY => 0,
	C_PARK => 0,
	C_PROC_INTRFCE => 0,
	C_REG_GRANTS => 0,
	C_DEV_BLK_ID => 0,
	C_DEV_MIR_ENABLE => 0)
PORT MAP (
	OPB_Clk => OPB_Clk,
	SYS_Rst => SYS_Rst,
	OPB_Rst => OPB_Rst,
	Debug_SYS_Rst => Debug_SYS_Rst,
	WDT_Rst => WDT_Rst,
	M_ABus => M_ABus,
	M_BE => M_BE,
	M_beXfer => M_beXfer,
	M_busLock => M_busLock,
	M_DBus => M_DBus,
	M_DBusEn => M_DBusEn,
	M_DBusEn32_63 => M_DBusEn32_63,
	M_dwXfer => M_dwXfer,
	M_fwXfer => M_fwXfer,
	M_hwXfer => M_hwXfer,
	M_request => M_request,
	M_RNW => M_RNW,
	M_select => M_select,
	M_seqAddr => M_seqAddr,
	Sl_beAck => Sl_beAck,
	Sl_DBus => Sl_DBus,
	Sl_DBusEn => Sl_DBusEn,
	Sl_DBusEn32_63 => Sl_DBusEn32_63,
	Sl_errAck => Sl_errAck,
	Sl_dwAck => Sl_dwAck,
	Sl_fwAck => Sl_fwAck,
	Sl_hwAck => Sl_hwAck,
	Sl_retry => Sl_retry,
	Sl_toutSup => Sl_toutSup,
	Sl_xferAck => Sl_xferAck,
	OPB_MRequest => OPB_MRequest,
	OPB_ABus => OPB_ABus,
	OPB_BE => OPB_BE,
	OPB_beXfer => OPB_beXfer,
	OPB_beAck => OPB_beAck,
	OPB_busLock => OPB_busLock,
	OPB_rdDBus => OPB_rdDBus,
	OPB_wrDBus => OPB_wrDBus,
	OPB_DBus => OPB_DBus,
	OPB_errAck => OPB_errAck,
	OPB_dwAck => OPB_dwAck,
	OPB_dwXfer => OPB_dwXfer,
	OPB_fwAck => OPB_fwAck,
	OPB_fwXfer => OPB_fwXfer,
	OPB_hwAck => OPB_hwAck,
	OPB_hwXfer => OPB_hwXfer,
	OPB_MGrant => OPB_MGrant,
	OPB_pendReq => OPB_pendReq,
	OPB_retry => OPB_retry,
	OPB_RNW => OPB_RNW,
	OPB_select => OPB_select,
	OPB_seqAddr => OPB_seqAddr,
	OPB_timeout => OPB_timeout,
	OPB_toutSup => OPB_toutSup,
	OPB_xferAck => OPB_xferAck);

END ARCHITECTURE IMP;
