--------------------------------------------------------------------------------
-- system.vhd
--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;

-- synthesis translate_off
LIBRARY UNISIM;
USE UNISIM.VCOMPONENTS.ALL;
-- synthesis translate_on

ENTITY system IS
PORT (
	-- instance GLOBAL
	RS232_TD : OUT STD_LOGIC;
	RS232_RD : IN STD_LOGIC;
	SDRAM_CE : OUT STD_LOGIC;
	AU_CSN : OUT STD_LOGIC;
	FLASH_CE : OUT STD_LOGIC;
	USB_CS : OUT STD_LOGIC;
	ADC_OE : OUT STD_LOGIC;
	NV_CS1 : OUT STD_LOGIC;
	NV_CS0 : OUT STD_LOGIC;

	-- instance clkgen_0
	FPGA_CLK1 : IN STD_LOGIC;

	-- instance sram_ethernet_0
	RAM_CE : OUT STD_LOGIC;
	ETH_RDY_DTAK : IN STD_LOGIC;
	PB_D : INOUT STD_LOGIC_VECTOR(15 DOWNTO 0);
	PB_WE_IOW : OUT STD_LOGIC;
	PB_A : OUT STD_LOGIC_VECTOR(17 DOWNTO 0);
	ETH_CS : OUT STD_LOGIC;
	PB_OE_IOR : OUT STD_LOGIC;
	PB_LB_AEN : OUT STD_LOGIC;
	PB_UB_BHE : OUT STD_LOGIC;
	ETH_IREQ : IN STD_LOGIC;
	ETH_IOCS : IN STD_LOGIC);
END system;

ARCHITECTURE IMP OF system IS

ATTRIBUTE BOX_TYPE : STRING;
--------------------------------------------------------------------------------
COMPONENT intc_wrapper IS
PORT (
	Intr : IN STD_LOGIC_VECTOR(0 DOWNTO 0);
	Irq : OUT STD_LOGIC;
	OPB_Clk : IN STD_LOGIC;
	OPB_Rst : IN STD_LOGIC;
	OPB_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	OPB_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	OPB_RNW : IN STD_LOGIC;
	OPB_select : IN STD_LOGIC;
	OPB_seqAddr : IN STD_LOGIC;
	OPB_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	IntC_DBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	IntC_errAck : OUT STD_LOGIC;
	IntC_retry : OUT STD_LOGIC;
	IntC_toutSup : OUT STD_LOGIC;
	IntC_xferAck : OUT STD_LOGIC);
END COMPONENT;
ATTRIBUTE box_type OF intc_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT d_lmb_wrapper IS
PORT (
	LMB_Clk : IN STD_LOGIC;
	SYS_Rst : IN STD_LOGIC;
	LMB_Rst : OUT STD_LOGIC;
	M_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	M_ReadStrobe : IN STD_LOGIC;
	M_WriteStrobe : IN STD_LOGIC;
	M_AddrStrobe : IN STD_LOGIC;
	M_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	M_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	Sl_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	Sl_Ready : IN STD_LOGIC_VECTOR(0 TO 0);
	LMB_ABus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_ReadStrobe : OUT STD_LOGIC;
	LMB_WriteStrobe : OUT STD_LOGIC;
	LMB_AddrStrobe : OUT STD_LOGIC;
	LMB_ReadDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_WriteDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_Ready : OUT STD_LOGIC;
	LMB_BE : OUT STD_LOGIC_VECTOR(0 TO 3));
END COMPONENT;
ATTRIBUTE box_type OF d_lmb_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT lmb_data_controller_wrapper IS
PORT (
	LMB_Clk : IN STD_LOGIC;
	LMB_Rst : IN STD_LOGIC;
	LMB_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	LMB_WriteDBus : IN STD_LOGIC_VECTOR(0 TO 31);
	LMB_AddrStrobe : IN STD_LOGIC;
	LMB_ReadStrobe : IN STD_LOGIC;
	LMB_WriteStrobe : IN STD_LOGIC;
	LMB_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	Sl_DBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	Sl_Ready : OUT STD_LOGIC;
	BRAM_Rst_A : OUT STD_LOGIC;
	BRAM_Clk_A : OUT STD_LOGIC;
	BRAM_EN_A : OUT STD_LOGIC;
	BRAM_WEN_A : OUT STD_LOGIC_VECTOR(0 TO 3);
	BRAM_Addr_A : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Din_A : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Dout_A : OUT STD_LOGIC_VECTOR(0 TO 31));
END COMPONENT;
ATTRIBUTE box_type OF lmb_data_controller_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT i_lmb_wrapper IS
PORT (
	LMB_Clk : IN STD_LOGIC;
	SYS_Rst : IN STD_LOGIC;
	LMB_Rst : OUT STD_LOGIC;
	M_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	M_ReadStrobe : IN STD_LOGIC;
	M_WriteStrobe : IN STD_LOGIC;
	M_AddrStrobe : IN STD_LOGIC;
	M_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	M_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	Sl_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	Sl_Ready : IN STD_LOGIC_VECTOR(0 TO 0);
	LMB_ABus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_ReadStrobe : OUT STD_LOGIC;
	LMB_WriteStrobe : OUT STD_LOGIC;
	LMB_AddrStrobe : OUT STD_LOGIC;
	LMB_ReadDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_WriteDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	LMB_Ready : OUT STD_LOGIC;
	LMB_BE : OUT STD_LOGIC_VECTOR(0 TO 3));
END COMPONENT;
ATTRIBUTE box_type OF i_lmb_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT lmb_instruction_controller_wrapper IS
PORT (
	LMB_Clk : IN STD_LOGIC;
	LMB_Rst : IN STD_LOGIC;
	LMB_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	LMB_WriteDBus : IN STD_LOGIC_VECTOR(0 TO 31);
	LMB_AddrStrobe : IN STD_LOGIC;
	LMB_ReadStrobe : IN STD_LOGIC;
	LMB_WriteStrobe : IN STD_LOGIC;
	LMB_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	Sl_DBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	Sl_Ready : OUT STD_LOGIC;
	BRAM_Rst_A : OUT STD_LOGIC;
	BRAM_Clk_A : OUT STD_LOGIC;
	BRAM_EN_A : OUT STD_LOGIC;
	BRAM_WEN_A : OUT STD_LOGIC_VECTOR(0 TO 3);
	BRAM_Addr_A : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Din_A : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Dout_A : OUT STD_LOGIC_VECTOR(0 TO 31));
END COMPONENT;
ATTRIBUTE box_type OF lmb_instruction_controller_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT bram_wrapper IS
PORT (
	BRAM_Rst_A : IN STD_LOGIC;
	BRAM_Clk_A : IN STD_LOGIC;
	BRAM_EN_A : IN STD_LOGIC;
	BRAM_WEN_A : IN STD_LOGIC_VECTOR(0 TO 3);
	BRAM_Addr_A : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Din_A : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Dout_A : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Rst_B : IN STD_LOGIC;
	BRAM_Clk_B : IN STD_LOGIC;
	BRAM_EN_B : IN STD_LOGIC;
	BRAM_WEN_B : IN STD_LOGIC_VECTOR(0 TO 3);
	BRAM_Addr_B : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Din_B : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Dout_B : IN STD_LOGIC_VECTOR(0 TO 31));
END COMPONENT;
ATTRIBUTE box_type OF bram_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT clkgen_0_wrapper IS
PORT (
	FPGA_CLK1 : IN STD_LOGIC;
	fpga_reset : OUT STD_LOGIC;
	pixel_clock : OUT STD_LOGIC;
	sys_clk : OUT STD_LOGIC);
END COMPONENT;
ATTRIBUTE box_type OF clkgen_0_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT myopb_bus_wrapper IS
PORT (
	OPB_Clk : IN STD_LOGIC;
	SYS_Rst : IN STD_LOGIC;
	OPB_Rst : OUT STD_LOGIC;
	Debug_SYS_Rst : IN STD_LOGIC;
	WDT_Rst : IN STD_LOGIC;
	M_ABus : IN STD_LOGIC_VECTOR(0 TO 63);
	M_BE : IN STD_LOGIC_VECTOR(0 TO 7);
	M_beXfer : IN STD_LOGIC_VECTOR(0 TO 1);
	M_busLock : IN STD_LOGIC_VECTOR(0 TO 1);
	M_DBus : IN STD_LOGIC_VECTOR(0 TO 63);
	M_DBusEn : IN STD_LOGIC_VECTOR(0 TO 1);
	M_DBusEn32_63 : IN STD_LOGIC_VECTOR(0 TO 1);
	M_dwXfer : IN STD_LOGIC_VECTOR(0 TO 1);
	M_fwXfer : IN STD_LOGIC_VECTOR(0 TO 1);
	M_hwXfer : IN STD_LOGIC_VECTOR(0 TO 1);
	M_request : IN STD_LOGIC_VECTOR(0 TO 1);
	M_RNW : IN STD_LOGIC_VECTOR(0 TO 1);
	M_select : IN STD_LOGIC_VECTOR(0 TO 1);
	M_seqAddr : IN STD_LOGIC_VECTOR(0 TO 1);
	Sl_beAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_DBus : IN STD_LOGIC_VECTOR(0 TO 95);
	Sl_DBusEn : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_DBusEn32_63 : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_errAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_dwAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_fwAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_hwAck : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_retry : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_toutSup : IN STD_LOGIC_VECTOR(0 TO 2);
	Sl_xferAck : IN STD_LOGIC_VECTOR(0 TO 2);
	OPB_MRequest : OUT STD_LOGIC_VECTOR(0 TO 1);
	OPB_ABus : OUT STD_LOGIC_VECTOR(0 TO 31);
	OPB_BE : OUT STD_LOGIC_VECTOR(0 TO 3);
	OPB_beXfer : OUT STD_LOGIC;
	OPB_beAck : OUT STD_LOGIC;
	OPB_busLock : OUT STD_LOGIC;
	OPB_rdDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	OPB_wrDBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	OPB_DBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	OPB_errAck : OUT STD_LOGIC;
	OPB_dwAck : OUT STD_LOGIC;
	OPB_dwXfer : OUT STD_LOGIC;
	OPB_fwAck : OUT STD_LOGIC;
	OPB_fwXfer : OUT STD_LOGIC;
	OPB_hwAck : OUT STD_LOGIC;
	OPB_hwXfer : OUT STD_LOGIC;
	OPB_MGrant : OUT STD_LOGIC_VECTOR(0 TO 1);
	OPB_pendReq : OUT STD_LOGIC_VECTOR(0 TO 1);
	OPB_retry : OUT STD_LOGIC;
	OPB_RNW : OUT STD_LOGIC;
	OPB_select : OUT STD_LOGIC;
	OPB_seqAddr : OUT STD_LOGIC;
	OPB_timeout : OUT STD_LOGIC;
	OPB_toutSup : OUT STD_LOGIC;
	OPB_xferAck : OUT STD_LOGIC);
END COMPONENT;
ATTRIBUTE box_type OF myopb_bus_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT myuart_wrapper IS
PORT (
	Interrupt : OUT STD_LOGIC;
	OPB_Clk : IN STD_LOGIC;
	RX : IN STD_LOGIC;
	TX : OUT STD_LOGIC;
	OPB_Rst : IN STD_LOGIC;
	OPB_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	OPB_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	OPB_RNW : IN STD_LOGIC;
	OPB_select : IN STD_LOGIC;
	OPB_seqAddr : IN STD_LOGIC;
	OPB_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	UART_DBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	UART_errAck : OUT STD_LOGIC;
	UART_retry : OUT STD_LOGIC;
	UART_toutSup : OUT STD_LOGIC;
	UART_xferAck : OUT STD_LOGIC);
END COMPONENT;
ATTRIBUTE box_type OF myuart_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT mymicroblaze_wrapper IS
PORT (
	CLK : IN STD_LOGIC;
	INTERRUPT : IN STD_LOGIC;
	RESET : IN STD_LOGIC;
	DEBUG_RST : IN STD_LOGIC;
	EXT_BRK : IN STD_LOGIC;
	EXT_NM_BRK : IN STD_LOGIC;
	DBG_STOP : IN STD_LOGIC;
	INSTR : IN STD_LOGIC_VECTOR(0 TO 31);
	IREADY : IN STD_LOGIC;
	INSTR_ADDR : OUT STD_LOGIC_VECTOR(0 TO 31);
	IFETCH : OUT STD_LOGIC;
	I_AS : OUT STD_LOGIC;
	DATA_READ : IN STD_LOGIC_VECTOR(0 TO 31);
	DREADY : IN STD_LOGIC;
	DATA_WRITE : OUT STD_LOGIC_VECTOR(0 TO 31);
	DATA_ADDR : OUT STD_LOGIC_VECTOR(0 TO 31);
	D_AS : OUT STD_LOGIC;
	READ_STROBE : OUT STD_LOGIC;
	WRITE_STROBE : OUT STD_LOGIC;
	BYTE_ENABLE : OUT STD_LOGIC_VECTOR(0 TO 3);
	DM_ABUS : OUT STD_LOGIC_VECTOR(0 TO 31);
	DM_BE : OUT STD_LOGIC_VECTOR(0 TO 3);
	DM_BUSLOCK : OUT STD_LOGIC;
	DM_DBUS : OUT STD_LOGIC_VECTOR(0 TO 31);
	DM_REQUEST : OUT STD_LOGIC;
	DM_RNW : OUT STD_LOGIC;
	DM_SELECT : OUT STD_LOGIC;
	DM_SEQADDR : OUT STD_LOGIC;
	DOPB_DBUS : IN STD_LOGIC_VECTOR(0 TO 31);
	DOPB_ERRACK : IN STD_LOGIC;
	DOPB_MGRANT : IN STD_LOGIC;
	DOPB_RETRY : IN STD_LOGIC;
	DOPB_TIMEOUT : IN STD_LOGIC;
	DOPB_XFERACK : IN STD_LOGIC;
	IM_ABUS : OUT STD_LOGIC_VECTOR(0 TO 31);
	IM_BE : OUT STD_LOGIC_VECTOR(0 TO 3);
	IM_BUSLOCK : OUT STD_LOGIC;
	IM_DBUS : OUT STD_LOGIC_VECTOR(0 TO 31);
	IM_REQUEST : OUT STD_LOGIC;
	IM_RNW : OUT STD_LOGIC;
	IM_SELECT : OUT STD_LOGIC;
	IM_SEQADDR : OUT STD_LOGIC;
	IOPB_DBUS : IN STD_LOGIC_VECTOR(0 TO 31);
	IOPB_ERRACK : IN STD_LOGIC;
	IOPB_MGRANT : IN STD_LOGIC;
	IOPB_RETRY : IN STD_LOGIC;
	IOPB_TIMEOUT : IN STD_LOGIC;
	IOPB_XFERACK : IN STD_LOGIC;
	DBG_CLK : IN STD_LOGIC;
	DBG_TDI : IN STD_LOGIC;
	DBG_TDO : OUT STD_LOGIC;
	DBG_REG_EN : IN STD_LOGIC_VECTOR(0 TO 4);
	DBG_CAPTURE : IN STD_LOGIC;
	DBG_UPDATE : IN STD_LOGIC;
	VALID_INSTR : OUT STD_LOGIC;
	PC_EX : OUT STD_LOGIC_VECTOR(0 TO 31);
	REG_WRITE : OUT STD_LOGIC;
	REG_ADDR : OUT STD_LOGIC_VECTOR(0 TO 4);
	MSR_REG : OUT STD_LOGIC_VECTOR(0 TO 7);
	NEW_REG_VALUE : OUT STD_LOGIC_VECTOR(0 TO 31);
	PIPE_RUNNING : OUT STD_LOGIC;
	INTERRUPT_TAKEN : OUT STD_LOGIC;
	JUMP_TAKEN : OUT STD_LOGIC;
	PREFETCH_ADDR : OUT STD_LOGIC_VECTOR(0 TO 3);
	MB_Halted : OUT STD_LOGIC;
	FSL0_S_CLK : OUT STD_LOGIC;
	FSL0_S_READ : OUT STD_LOGIC;
	FSL0_S_DATA : IN STD_LOGIC_VECTOR(0 TO 31);
	FSL0_S_CONTROL : IN STD_LOGIC;
	FSL0_S_EXISTS : IN STD_LOGIC;
	FSL0_M_CLK : OUT STD_LOGIC;
	FSL0_M_WRITE : OUT STD_LOGIC;
	FSL0_M_DATA : OUT STD_LOGIC_VECTOR(0 TO 31);
	FSL0_M_CONTROL : OUT STD_LOGIC;
	FSL0_M_FULL : IN STD_LOGIC;
	FSL1_S_CLK : OUT STD_LOGIC;
	FSL1_S_READ : OUT STD_LOGIC;
	FSL1_S_DATA : IN STD_LOGIC_VECTOR(0 TO 31);
	FSL1_S_CONTROL : IN STD_LOGIC;
	FSL1_S_EXISTS : IN STD_LOGIC;
	FSL1_M_CLK : OUT STD_LOGIC;
	FSL1_M_WRITE : OUT STD_LOGIC;
	FSL1_M_DATA : OUT STD_LOGIC_VECTOR(0 TO 31);
	FSL1_M_CONTROL : OUT STD_LOGIC;
	FSL1_M_FULL : IN STD_LOGIC;
	FSL2_S_CLK : OUT STD_LOGIC;
	FSL2_S_READ : OUT STD_LOGIC;
	FSL2_S_DATA : IN STD_LOGIC_VECTOR(0 TO 31);
	FSL2_S_CONTROL : IN STD_LOGIC;
	FSL2_S_EXISTS : IN STD_LOGIC;
	FSL2_M_CLK : OUT STD_LOGIC;
	FSL2_M_WRITE : OUT STD_LOGIC;
	FSL2_M_DATA : OUT STD_LOGIC_VECTOR(0 TO 31);
	FSL2_M_CONTROL : OUT STD_LOGIC;
	FSL2_M_FULL : IN STD_LOGIC;
	FSL3_S_CLK : OUT STD_LOGIC;
	FSL3_S_READ : OUT STD_LOGIC;
	FSL3_S_DATA : IN STD_LOGIC_VECTOR(0 TO 31);
	FSL3_S_CONTROL : IN STD_LOGIC;
	FSL3_S_EXISTS : IN STD_LOGIC;
	FSL3_M_CLK : OUT STD_LOGIC;
	FSL3_M_WRITE : OUT STD_LOGIC;
	FSL3_M_DATA : OUT STD_LOGIC_VECTOR(0 TO 31);
	FSL3_M_CONTROL : OUT STD_LOGIC;
	FSL3_M_FULL : IN STD_LOGIC;
	FSL4_S_CLK : OUT STD_LOGIC;
	FSL4_S_READ : OUT STD_LOGIC;
	FSL4_S_DATA : IN STD_LOGIC_VECTOR(0 TO 31);
	FSL4_S_CONTROL : IN STD_LOGIC;
	FSL4_S_EXISTS : IN STD_LOGIC;
	FSL4_M_CLK : OUT STD_LOGIC;
	FSL4_M_WRITE : OUT STD_LOGIC;
	FSL4_M_DATA : OUT STD_LOGIC_VECTOR(0 TO 31);
	FSL4_M_CONTROL : OUT STD_LOGIC;
	FSL4_M_FULL : IN STD_LOGIC;
	FSL5_S_CLK : OUT STD_LOGIC;
	FSL5_S_READ : OUT STD_LOGIC;
	FSL5_S_DATA : IN STD_LOGIC_VECTOR(0 TO 31);
	FSL5_S_CONTROL : IN STD_LOGIC;
	FSL5_S_EXISTS : IN STD_LOGIC;
	FSL5_M_CLK : OUT STD_LOGIC;
	FSL5_M_WRITE : OUT STD_LOGIC;
	FSL5_M_DATA : OUT STD_LOGIC_VECTOR(0 TO 31);
	FSL5_M_CONTROL : OUT STD_LOGIC;
	FSL5_M_FULL : IN STD_LOGIC;
	FSL6_S_CLK : OUT STD_LOGIC;
	FSL6_S_READ : OUT STD_LOGIC;
	FSL6_S_DATA : IN STD_LOGIC_VECTOR(0 TO 31);
	FSL6_S_CONTROL : IN STD_LOGIC;
	FSL6_S_EXISTS : IN STD_LOGIC;
	FSL6_M_CLK : OUT STD_LOGIC;
	FSL6_M_WRITE : OUT STD_LOGIC;
	FSL6_M_DATA : OUT STD_LOGIC_VECTOR(0 TO 31);
	FSL6_M_CONTROL : OUT STD_LOGIC;
	FSL6_M_FULL : IN STD_LOGIC;
	FSL7_S_CLK : OUT STD_LOGIC;
	FSL7_S_READ : OUT STD_LOGIC;
	FSL7_S_DATA : IN STD_LOGIC_VECTOR(0 TO 31);
	FSL7_S_CONTROL : IN STD_LOGIC;
	FSL7_S_EXISTS : IN STD_LOGIC;
	FSL7_M_CLK : OUT STD_LOGIC;
	FSL7_M_WRITE : OUT STD_LOGIC;
	FSL7_M_DATA : OUT STD_LOGIC_VECTOR(0 TO 31);
	FSL7_M_CONTROL : OUT STD_LOGIC;
	FSL7_M_FULL : IN STD_LOGIC);
END COMPONENT;
ATTRIBUTE box_type OF mymicroblaze_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT sram_ethernet_0_wrapper IS
PORT (
	ETH_CS : OUT STD_LOGIC;
	ETH_IOCS : IN STD_LOGIC;
	ETH_IREQ : IN STD_LOGIC;
	ETH_RDY_DTAK : IN STD_LOGIC;
	OPB_Clk : IN STD_LOGIC;
	PB_A : OUT STD_LOGIC_VECTOR(0 TO 17);
	PB_D : INOUT STD_LOGIC_VECTOR(0 TO 15);
	PB_LB_AEN : OUT STD_LOGIC;
	PB_OE_IOR : OUT STD_LOGIC;
	PB_UB_BHE : OUT STD_LOGIC;
	PB_WE_IOW : OUT STD_LOGIC;
	RAM_CE : OUT STD_LOGIC;
	FLASH_CE : OUT STD_LOGIC;
	SDRAM_CE : OUT STD_LOGIC;
	ADC_OE : OUT STD_LOGIC;
	AU_CSN : OUT STD_LOGIC;
	USB_CS : OUT STD_LOGIC;
	NV_CS0 : OUT STD_LOGIC;
	NV_CS1 : OUT STD_LOGIC;
	OPB_Rst : IN STD_LOGIC;
	OPB_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	OPB_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	OPB_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	OPB_RNW : IN STD_LOGIC;
	OPB_select : IN STD_LOGIC;
	OPB_seqAddr : IN STD_LOGIC;
	Sln_DBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	Sln_errAck : OUT STD_LOGIC;
	Sln_retry : OUT STD_LOGIC;
	Sln_toutSup : OUT STD_LOGIC;
	Sln_xferAck : OUT STD_LOGIC);
END COMPONENT;
ATTRIBUTE box_type OF sram_ethernet_0_wrapper : COMPONENT IS "black_box";
--------------------------------------------------------------------------------
COMPONENT OBUF IS
PORT (
	O : OUT STD_LOGIC;
	I : IN STD_LOGIC);
END COMPONENT;
--------------------------------------------------------------------------------
COMPONENT IBUF IS
PORT (
	O : OUT STD_LOGIC;
	I : IN STD_LOGIC);
END COMPONENT;

--------------------------------------------------------------------------------
-- internal signals
--------------------------------------------------------------------------------

	SIGNAL ADC_OE_OBUF : STD_LOGIC;

	SIGNAL AU_CSN_OBUF : STD_LOGIC;

	SIGNAL FLASH_CE_OBUF : STD_LOGIC;

	SIGNAL NV_CS0_OBUF : STD_LOGIC;

	SIGNAL NV_CS1_OBUF : STD_LOGIC;

	SIGNAL RS232_RD_IBUF : STD_LOGIC;

	SIGNAL RS232_TD_OBUF : STD_LOGIC;

	SIGNAL SDRAM_CE_OBUF : STD_LOGIC;

	SIGNAL USB_CS_OBUF : STD_LOGIC;

	SIGNAL conn_0_BRAM_Addr : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL conn_0_BRAM_Clk : STD_LOGIC;

	SIGNAL conn_0_BRAM_Din : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL conn_0_BRAM_Dout : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL conn_0_BRAM_EN : STD_LOGIC;

	SIGNAL conn_0_BRAM_Rst : STD_LOGIC;

	SIGNAL conn_0_BRAM_WEN : STD_LOGIC_VECTOR(0 TO 3);

	SIGNAL conn_1_BRAM_Addr : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL conn_1_BRAM_Clk : STD_LOGIC;

	SIGNAL conn_1_BRAM_Din : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL conn_1_BRAM_Dout : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL conn_1_BRAM_EN : STD_LOGIC;

	SIGNAL conn_1_BRAM_Rst : STD_LOGIC;

	SIGNAL conn_1_BRAM_WEN : STD_LOGIC_VECTOR(0 TO 3);

	SIGNAL d_lmb_LMB_ABus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL d_lmb_LMB_AddrStrobe : STD_LOGIC;

	SIGNAL d_lmb_LMB_BE : STD_LOGIC_VECTOR(0 TO 3);

	SIGNAL d_lmb_LMB_ReadDBus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL d_lmb_LMB_ReadStrobe : STD_LOGIC;

	SIGNAL d_lmb_LMB_Ready : STD_LOGIC;

	SIGNAL d_lmb_LMB_WriteDBus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL d_lmb_LMB_WriteStrobe : STD_LOGIC;

	SIGNAL d_lmb_M_ABus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL d_lmb_M_AddrStrobe : STD_LOGIC;

	SIGNAL d_lmb_M_BE : STD_LOGIC_VECTOR(0 TO 3);

	SIGNAL d_lmb_M_DBus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL d_lmb_M_ReadStrobe : STD_LOGIC;

	SIGNAL d_lmb_M_WriteStrobe : STD_LOGIC;

	SIGNAL d_lmb_OPB_Rst : STD_LOGIC;

	SIGNAL d_lmb_Sl_DBus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL d_lmb_Sl_Ready : STD_LOGIC_VECTOR(0 TO 0);

	SIGNAL fpga_reset : STD_LOGIC;

	SIGNAL i_lmb_LMB_ABus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL i_lmb_LMB_AddrStrobe : STD_LOGIC;

	SIGNAL i_lmb_LMB_BE : STD_LOGIC_VECTOR(0 TO 3);

	SIGNAL i_lmb_LMB_ReadDBus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL i_lmb_LMB_ReadStrobe : STD_LOGIC;

	SIGNAL i_lmb_LMB_Ready : STD_LOGIC;

	SIGNAL i_lmb_LMB_WriteDBus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL i_lmb_LMB_WriteStrobe : STD_LOGIC;

	SIGNAL i_lmb_M_ABus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL i_lmb_M_AddrStrobe : STD_LOGIC;

	SIGNAL i_lmb_M_ReadStrobe : STD_LOGIC;

	SIGNAL i_lmb_OPB_Rst : STD_LOGIC;

	SIGNAL i_lmb_Sl_DBus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL i_lmb_Sl_Ready : STD_LOGIC_VECTOR(0 TO 0);

	SIGNAL intc_intr_vec : STD_LOGIC_VECTOR(0 DOWNTO 0);

	SIGNAL intr : STD_LOGIC;

	SIGNAL myopb_bus_M_ABus : STD_LOGIC_VECTOR(0 TO 63);

	SIGNAL myopb_bus_M_BE : STD_LOGIC_VECTOR(0 TO 7);

	SIGNAL myopb_bus_M_DBus : STD_LOGIC_VECTOR(0 TO 63);

	SIGNAL myopb_bus_M_RNW : STD_LOGIC_VECTOR(0 TO 1);

	SIGNAL myopb_bus_M_busLock : STD_LOGIC_VECTOR(0 TO 1);

	SIGNAL myopb_bus_M_request : STD_LOGIC_VECTOR(0 TO 1);

	SIGNAL myopb_bus_M_select : STD_LOGIC_VECTOR(0 TO 1);

	SIGNAL myopb_bus_M_seqAddr : STD_LOGIC_VECTOR(0 TO 1);

	SIGNAL myopb_bus_OPB_ABus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL myopb_bus_OPB_BE : STD_LOGIC_VECTOR(0 TO 3);

	SIGNAL myopb_bus_OPB_DBus : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL myopb_bus_OPB_MGrant : STD_LOGIC_VECTOR(0 TO 1);

	SIGNAL myopb_bus_OPB_RNW : STD_LOGIC;

	SIGNAL myopb_bus_OPB_Rst : STD_LOGIC;

	SIGNAL myopb_bus_OPB_errAck : STD_LOGIC;

	SIGNAL myopb_bus_OPB_retry : STD_LOGIC;

	SIGNAL myopb_bus_OPB_select : STD_LOGIC;

	SIGNAL myopb_bus_OPB_seqAddr : STD_LOGIC;

	SIGNAL myopb_bus_OPB_timeout : STD_LOGIC;

	SIGNAL myopb_bus_OPB_xferAck : STD_LOGIC;

	SIGNAL myopb_bus_Sl_DBus : STD_LOGIC_VECTOR(0 TO 95);

	SIGNAL myopb_bus_Sl_errAck : STD_LOGIC_VECTOR(0 TO 2);

	SIGNAL myopb_bus_Sl_retry : STD_LOGIC_VECTOR(0 TO 2);

	SIGNAL myopb_bus_Sl_toutSup : STD_LOGIC_VECTOR(0 TO 2);

	SIGNAL myopb_bus_Sl_xferAck : STD_LOGIC_VECTOR(0 TO 2);

	SIGNAL net_gnd0 : STD_LOGIC;

	SIGNAL net_gnd2 : STD_LOGIC_VECTOR(0 TO 1);

	SIGNAL net_gnd3 : STD_LOGIC_VECTOR(0 TO 2);

	SIGNAL net_gnd32 : STD_LOGIC_VECTOR(0 TO 31);

	SIGNAL net_gnd4 : STD_LOGIC_VECTOR(0 TO 3);

	SIGNAL net_gnd5 : STD_LOGIC_VECTOR(0 TO 4);

	SIGNAL net_vcc2 : STD_LOGIC_VECTOR(0 TO 1);

	SIGNAL net_vcc3 : STD_LOGIC_VECTOR(0 TO 2);

	SIGNAL sys_clk : STD_LOGIC;

	SIGNAL uart_intr : STD_LOGIC;

BEGIN

--------------------------------------------------------------------------------
-- Power assignments
net_gnd0 <= '0';
net_gnd2 <= "00";
net_gnd3 <= "000";
net_gnd32 <= "00000000000000000000000000000000";
net_gnd4 <= "0000";
net_gnd5 <= "00000";
net_vcc2 <= "11";
net_vcc3 <= "111";
--------------------------------------------------------------------------------
-- Constant assignments
--------------------------------------------------------------------------------
-- Top-level port assignments
--------------------------------------------------------------------------------
-- Lower-level assignments
intc_intr_vec(0) <= uart_intr;

--------------------------------------------------------------------------------
intc : intc_wrapper
PORT MAP (
	Intr => intc_intr_vec,
	Irq => intr,
	OPB_Clk => sys_clk,
	OPB_Rst => myopb_bus_OPB_Rst,
	OPB_ABus => myopb_bus_OPB_ABus,
	OPB_BE => myopb_bus_OPB_BE,
	OPB_RNW => myopb_bus_OPB_RNW,
	OPB_select => myopb_bus_OPB_select,
	OPB_seqAddr => myopb_bus_OPB_seqAddr,
	OPB_DBus => myopb_bus_OPB_DBus,
	IntC_DBus => myopb_bus_Sl_DBus(0 TO 31),
	IntC_errAck => myopb_bus_Sl_errAck(0),
	IntC_retry => myopb_bus_Sl_retry(0),
	IntC_toutSup => myopb_bus_Sl_toutSup(0),
	IntC_xferAck => myopb_bus_Sl_xferAck(0));

--------------------------------------------------------------------------------
d_lmb : d_lmb_wrapper
PORT MAP (
	LMB_Clk => sys_clk,
	SYS_Rst => fpga_reset,
	LMB_Rst => d_lmb_OPB_Rst,
	M_ABus => d_lmb_M_ABus,
	M_ReadStrobe => d_lmb_M_ReadStrobe,
	M_WriteStrobe => d_lmb_M_WriteStrobe,
	M_AddrStrobe => d_lmb_M_AddrStrobe,
	M_DBus => d_lmb_M_DBus,
	M_BE => d_lmb_M_BE,
	Sl_DBus => d_lmb_Sl_DBus,
	Sl_Ready => d_lmb_Sl_Ready,
	LMB_ABus => d_lmb_LMB_ABus,
	LMB_ReadStrobe => d_lmb_LMB_ReadStrobe,
	LMB_WriteStrobe => d_lmb_LMB_WriteStrobe,
	LMB_AddrStrobe => d_lmb_LMB_AddrStrobe,
	LMB_ReadDBus => d_lmb_LMB_ReadDBus,
	LMB_WriteDBus => d_lmb_LMB_WriteDBus,
	LMB_Ready => d_lmb_LMB_Ready,
	LMB_BE => d_lmb_LMB_BE);

--------------------------------------------------------------------------------
lmb_data_controller : lmb_data_controller_wrapper
PORT MAP (
	LMB_Clk => sys_clk,
	LMB_Rst => d_lmb_OPB_Rst,
	LMB_ABus => d_lmb_LMB_ABus,
	LMB_WriteDBus => d_lmb_LMB_WriteDBus,
	LMB_AddrStrobe => d_lmb_LMB_AddrStrobe,
	LMB_ReadStrobe => d_lmb_LMB_ReadStrobe,
	LMB_WriteStrobe => d_lmb_LMB_WriteStrobe,
	LMB_BE => d_lmb_LMB_BE,
	Sl_DBus => d_lmb_Sl_DBus,
	Sl_Ready => d_lmb_Sl_Ready(0),
	BRAM_Rst_A => conn_0_BRAM_Rst,
	BRAM_Clk_A => conn_0_BRAM_Clk,
	BRAM_EN_A => conn_0_BRAM_EN,
	BRAM_WEN_A => conn_0_BRAM_WEN,
	BRAM_Addr_A => conn_0_BRAM_Addr,
	BRAM_Din_A => conn_0_BRAM_Din,
	BRAM_Dout_A => conn_0_BRAM_Dout);

--------------------------------------------------------------------------------
i_lmb : i_lmb_wrapper
PORT MAP (
	LMB_Clk => sys_clk,
	SYS_Rst => fpga_reset,
	LMB_Rst => i_lmb_OPB_Rst,
	M_ABus => i_lmb_M_ABus,
	M_ReadStrobe => i_lmb_M_ReadStrobe,
	M_WriteStrobe => net_gnd0,
	M_AddrStrobe => i_lmb_M_AddrStrobe,
	M_DBus => net_gnd32,
	M_BE => net_gnd4,
	Sl_DBus => i_lmb_Sl_DBus,
	Sl_Ready => i_lmb_Sl_Ready,
	LMB_ABus => i_lmb_LMB_ABus,
	LMB_ReadStrobe => i_lmb_LMB_ReadStrobe,
	LMB_WriteStrobe => i_lmb_LMB_WriteStrobe,
	LMB_AddrStrobe => i_lmb_LMB_AddrStrobe,
	LMB_ReadDBus => i_lmb_LMB_ReadDBus,
	LMB_WriteDBus => i_lmb_LMB_WriteDBus,
	LMB_Ready => i_lmb_LMB_Ready,
	LMB_BE => i_lmb_LMB_BE);

--------------------------------------------------------------------------------
lmb_instruction_controller : lmb_instruction_controller_wrapper
PORT MAP (
	LMB_Clk => sys_clk,
	LMB_Rst => i_lmb_OPB_Rst,
	LMB_ABus => i_lmb_LMB_ABus,
	LMB_WriteDBus => i_lmb_LMB_WriteDBus,
	LMB_AddrStrobe => i_lmb_LMB_AddrStrobe,
	LMB_ReadStrobe => i_lmb_LMB_ReadStrobe,
	LMB_WriteStrobe => i_lmb_LMB_WriteStrobe,
	LMB_BE => i_lmb_LMB_BE,
	Sl_DBus => i_lmb_Sl_DBus,
	Sl_Ready => i_lmb_Sl_Ready(0),
	BRAM_Rst_A => conn_1_BRAM_Rst,
	BRAM_Clk_A => conn_1_BRAM_Clk,
	BRAM_EN_A => conn_1_BRAM_EN,
	BRAM_WEN_A => conn_1_BRAM_WEN,
	BRAM_Addr_A => conn_1_BRAM_Addr,
	BRAM_Din_A => conn_1_BRAM_Din,
	BRAM_Dout_A => conn_1_BRAM_Dout);

--------------------------------------------------------------------------------
bram : bram_wrapper
PORT MAP (
	BRAM_Rst_A => conn_0_BRAM_Rst,
	BRAM_Clk_A => conn_0_BRAM_Clk,
	BRAM_EN_A => conn_0_BRAM_EN,
	BRAM_WEN_A => conn_0_BRAM_WEN,
	BRAM_Addr_A => conn_0_BRAM_Addr,
	BRAM_Din_A => conn_0_BRAM_Din,
	BRAM_Dout_A => conn_0_BRAM_Dout,
	BRAM_Rst_B => conn_1_BRAM_Rst,
	BRAM_Clk_B => conn_1_BRAM_Clk,
	BRAM_EN_B => conn_1_BRAM_EN,
	BRAM_WEN_B => conn_1_BRAM_WEN,
	BRAM_Addr_B => conn_1_BRAM_Addr,
	BRAM_Din_B => conn_1_BRAM_Din,
	BRAM_Dout_B => conn_1_BRAM_Dout);

--------------------------------------------------------------------------------
clkgen_0 : clkgen_0_wrapper
PORT MAP (
	FPGA_CLK1 => FPGA_CLK1,
	fpga_reset => fpga_reset,
	pixel_clock => open,
	sys_clk => sys_clk);

--------------------------------------------------------------------------------
myopb_bus : myopb_bus_wrapper
PORT MAP (
	OPB_Clk => sys_clk,
	SYS_Rst => fpga_reset,
	OPB_Rst => myopb_bus_OPB_Rst,
	Debug_SYS_Rst => net_gnd0,
	WDT_Rst => net_gnd0,
	M_ABus => myopb_bus_M_ABus,
	M_BE => myopb_bus_M_BE,
	M_beXfer => net_gnd2,
	M_busLock => myopb_bus_M_busLock,
	M_DBus => myopb_bus_M_DBus,
	M_DBusEn => net_gnd2,
	M_DBusEn32_63 => net_vcc2,
	M_dwXfer => net_gnd2,
	M_fwXfer => net_gnd2,
	M_hwXfer => net_gnd2,
	M_request => myopb_bus_M_request,
	M_RNW => myopb_bus_M_RNW,
	M_select => myopb_bus_M_select,
	M_seqAddr => myopb_bus_M_seqAddr,
	Sl_beAck => net_gnd3,
	Sl_DBus => myopb_bus_Sl_DBus,
	Sl_DBusEn => net_vcc3,
	Sl_DBusEn32_63 => net_vcc3,
	Sl_errAck => myopb_bus_Sl_errAck,
	Sl_dwAck => net_gnd3,
	Sl_fwAck => net_gnd3,
	Sl_hwAck => net_gnd3,
	Sl_retry => myopb_bus_Sl_retry,
	Sl_toutSup => myopb_bus_Sl_toutSup,
	Sl_xferAck => myopb_bus_Sl_xferAck,
	OPB_MRequest => open,
	OPB_ABus => myopb_bus_OPB_ABus,
	OPB_BE => myopb_bus_OPB_BE,
	OPB_beXfer => open,
	OPB_beAck => open,
	OPB_busLock => open,
	OPB_rdDBus => open,
	OPB_wrDBus => open,
	OPB_DBus => myopb_bus_OPB_DBus,
	OPB_errAck => myopb_bus_OPB_errAck,
	OPB_dwAck => open,
	OPB_dwXfer => open,
	OPB_fwAck => open,
	OPB_fwXfer => open,
	OPB_hwAck => open,
	OPB_hwXfer => open,
	OPB_MGrant => myopb_bus_OPB_MGrant,
	OPB_pendReq => open,
	OPB_retry => myopb_bus_OPB_retry,
	OPB_RNW => myopb_bus_OPB_RNW,
	OPB_select => myopb_bus_OPB_select,
	OPB_seqAddr => myopb_bus_OPB_seqAddr,
	OPB_timeout => myopb_bus_OPB_timeout,
	OPB_toutSup => open,
	OPB_xferAck => myopb_bus_OPB_xferAck);

--------------------------------------------------------------------------------
myuart : myuart_wrapper
PORT MAP (
	Interrupt => uart_intr,
	OPB_Clk => sys_clk,
	RX => RS232_RD_IBUF,
	TX => RS232_TD_OBUF,
	OPB_Rst => myopb_bus_OPB_Rst,
	OPB_ABus => myopb_bus_OPB_ABus,
	OPB_BE => myopb_bus_OPB_BE,
	OPB_RNW => myopb_bus_OPB_RNW,
	OPB_select => myopb_bus_OPB_select,
	OPB_seqAddr => myopb_bus_OPB_seqAddr,
	OPB_DBus => myopb_bus_OPB_DBus,
	UART_DBus => myopb_bus_Sl_DBus(32 TO 63),
	UART_errAck => myopb_bus_Sl_errAck(1),
	UART_retry => myopb_bus_Sl_retry(1),
	UART_toutSup => myopb_bus_Sl_toutSup(1),
	UART_xferAck => myopb_bus_Sl_xferAck(1));

--------------------------------------------------------------------------------
mymicroblaze : mymicroblaze_wrapper
PORT MAP (
	CLK => sys_clk,
	INTERRUPT => intr,
	RESET => fpga_reset,
	DEBUG_RST => net_gnd0,
	EXT_BRK => net_gnd0,
	EXT_NM_BRK => net_gnd0,
	DBG_STOP => net_gnd0,
	INSTR => i_lmb_LMB_ReadDBus,
	IREADY => i_lmb_LMB_Ready,
	INSTR_ADDR => i_lmb_M_ABus,
	IFETCH => i_lmb_M_ReadStrobe,
	I_AS => i_lmb_M_AddrStrobe,
	DATA_READ => d_lmb_LMB_ReadDBus,
	DREADY => d_lmb_LMB_Ready,
	DATA_WRITE => d_lmb_M_DBus,
	DATA_ADDR => d_lmb_M_ABus,
	D_AS => d_lmb_M_AddrStrobe,
	READ_STROBE => d_lmb_M_ReadStrobe,
	WRITE_STROBE => d_lmb_M_WriteStrobe,
	BYTE_ENABLE => d_lmb_M_BE,
	DM_ABUS => myopb_bus_M_ABus(0 TO 31),
	DM_BE => myopb_bus_M_BE(0 TO 3),
	DM_BUSLOCK => myopb_bus_M_busLock(0),
	DM_DBUS => myopb_bus_M_DBus(0 TO 31),
	DM_REQUEST => myopb_bus_M_request(0),
	DM_RNW => myopb_bus_M_RNW(0),
	DM_SELECT => myopb_bus_M_select(0),
	DM_SEQADDR => myopb_bus_M_seqAddr(0),
	DOPB_DBUS => myopb_bus_OPB_DBus,
	DOPB_ERRACK => myopb_bus_OPB_errAck,
	DOPB_MGRANT => myopb_bus_OPB_MGrant(0),
	DOPB_RETRY => myopb_bus_OPB_retry,
	DOPB_TIMEOUT => myopb_bus_OPB_timeout,
	DOPB_XFERACK => myopb_bus_OPB_xferAck,
	IM_ABUS => myopb_bus_M_ABus(32 TO 63),
	IM_BE => myopb_bus_M_BE(4 TO 7),
	IM_BUSLOCK => myopb_bus_M_busLock(1),
	IM_DBUS => myopb_bus_M_DBus(32 TO 63),
	IM_REQUEST => myopb_bus_M_request(1),
	IM_RNW => myopb_bus_M_RNW(1),
	IM_SELECT => myopb_bus_M_select(1),
	IM_SEQADDR => myopb_bus_M_seqAddr(1),
	IOPB_DBUS => myopb_bus_OPB_DBus,
	IOPB_ERRACK => myopb_bus_OPB_errAck,
	IOPB_MGRANT => myopb_bus_OPB_MGrant(1),
	IOPB_RETRY => myopb_bus_OPB_retry,
	IOPB_TIMEOUT => myopb_bus_OPB_timeout,
	IOPB_XFERACK => myopb_bus_OPB_xferAck,
	DBG_CLK => net_gnd0,
	DBG_TDI => net_gnd0,
	DBG_TDO => open,
	DBG_REG_EN => net_gnd5,
	DBG_CAPTURE => net_gnd0,
	DBG_UPDATE => net_gnd0,
	VALID_INSTR => open,
	PC_EX => open,
	REG_WRITE => open,
	REG_ADDR => open,
	MSR_REG => open,
	NEW_REG_VALUE => open,
	PIPE_RUNNING => open,
	INTERRUPT_TAKEN => open,
	JUMP_TAKEN => open,
	PREFETCH_ADDR => open,
	MB_Halted => open,
	FSL0_S_CLK => open,
	FSL0_S_READ => open,
	FSL0_S_DATA => net_gnd32,
	FSL0_S_CONTROL => net_gnd0,
	FSL0_S_EXISTS => net_gnd0,
	FSL0_M_CLK => open,
	FSL0_M_WRITE => open,
	FSL0_M_DATA => open,
	FSL0_M_CONTROL => open,
	FSL0_M_FULL => net_gnd0,
	FSL1_S_CLK => open,
	FSL1_S_READ => open,
	FSL1_S_DATA => net_gnd32,
	FSL1_S_CONTROL => net_gnd0,
	FSL1_S_EXISTS => net_gnd0,
	FSL1_M_CLK => open,
	FSL1_M_WRITE => open,
	FSL1_M_DATA => open,
	FSL1_M_CONTROL => open,
	FSL1_M_FULL => net_gnd0,
	FSL2_S_CLK => open,
	FSL2_S_READ => open,
	FSL2_S_DATA => net_gnd32,
	FSL2_S_CONTROL => net_gnd0,
	FSL2_S_EXISTS => net_gnd0,
	FSL2_M_CLK => open,
	FSL2_M_WRITE => open,
	FSL2_M_DATA => open,
	FSL2_M_CONTROL => open,
	FSL2_M_FULL => net_gnd0,
	FSL3_S_CLK => open,
	FSL3_S_READ => open,
	FSL3_S_DATA => net_gnd32,
	FSL3_S_CONTROL => net_gnd0,
	FSL3_S_EXISTS => net_gnd0,
	FSL3_M_CLK => open,
	FSL3_M_WRITE => open,
	FSL3_M_DATA => open,
	FSL3_M_CONTROL => open,
	FSL3_M_FULL => net_gnd0,
	FSL4_S_CLK => open,
	FSL4_S_READ => open,
	FSL4_S_DATA => net_gnd32,
	FSL4_S_CONTROL => net_gnd0,
	FSL4_S_EXISTS => net_gnd0,
	FSL4_M_CLK => open,
	FSL4_M_WRITE => open,
	FSL4_M_DATA => open,
	FSL4_M_CONTROL => open,
	FSL4_M_FULL => net_gnd0,
	FSL5_S_CLK => open,
	FSL5_S_READ => open,
	FSL5_S_DATA => net_gnd32,
	FSL5_S_CONTROL => net_gnd0,
	FSL5_S_EXISTS => net_gnd0,
	FSL5_M_CLK => open,
	FSL5_M_WRITE => open,
	FSL5_M_DATA => open,
	FSL5_M_CONTROL => open,
	FSL5_M_FULL => net_gnd0,
	FSL6_S_CLK => open,
	FSL6_S_READ => open,
	FSL6_S_DATA => net_gnd32,
	FSL6_S_CONTROL => net_gnd0,
	FSL6_S_EXISTS => net_gnd0,
	FSL6_M_CLK => open,
	FSL6_M_WRITE => open,
	FSL6_M_DATA => open,
	FSL6_M_CONTROL => open,
	FSL6_M_FULL => net_gnd0,
	FSL7_S_CLK => open,
	FSL7_S_READ => open,
	FSL7_S_DATA => net_gnd32,
	FSL7_S_CONTROL => net_gnd0,
	FSL7_S_EXISTS => net_gnd0,
	FSL7_M_CLK => open,
	FSL7_M_WRITE => open,
	FSL7_M_DATA => open,
	FSL7_M_CONTROL => open,
	FSL7_M_FULL => net_gnd0);

--------------------------------------------------------------------------------
sram_ethernet_0 : sram_ethernet_0_wrapper
PORT MAP (
	ETH_CS => ETH_CS,
	ETH_IOCS => ETH_IOCS,
	ETH_IREQ => ETH_IREQ,
	ETH_RDY_DTAK => ETH_RDY_DTAK,
	OPB_Clk => sys_clk,
	PB_A => PB_A,
	PB_D => PB_D,
	PB_LB_AEN => PB_LB_AEN,
	PB_OE_IOR => PB_OE_IOR,
	PB_UB_BHE => PB_UB_BHE,
	PB_WE_IOW => PB_WE_IOW,
	RAM_CE => RAM_CE,
	FLASH_CE => FLASH_CE_OBUF,
	SDRAM_CE => SDRAM_CE_OBUF,
	ADC_OE => ADC_OE_OBUF,
	AU_CSN => AU_CSN_OBUF,
	USB_CS => USB_CS_OBUF,
	NV_CS0 => NV_CS0_OBUF,
	NV_CS1 => NV_CS1_OBUF,
	OPB_Rst => myopb_bus_OPB_Rst,
	OPB_ABus => myopb_bus_OPB_ABus,
	OPB_BE => myopb_bus_OPB_BE,
	OPB_DBus => myopb_bus_OPB_DBus,
	OPB_RNW => myopb_bus_OPB_RNW,
	OPB_select => myopb_bus_OPB_select,
	OPB_seqAddr => myopb_bus_OPB_seqAddr,
	Sln_DBus => myopb_bus_Sl_DBus(64 TO 95),
	Sln_errAck => myopb_bus_Sl_errAck(2),
	Sln_retry => myopb_bus_Sl_retry(2),
	Sln_toutSup => myopb_bus_Sl_toutSup(2),
	Sln_xferAck => myopb_bus_Sl_xferAck(2));

--------------------------------------------------------------------------------
obuf_0 : OBUF
PORT MAP (
	O => FLASH_CE,
	I => FLASH_CE_OBUF);

--------------------------------------------------------------------------------
obuf_1 : OBUF
PORT MAP (
	O => SDRAM_CE,
	I => SDRAM_CE_OBUF);

--------------------------------------------------------------------------------
obuf_2 : OBUF
PORT MAP (
	O => ADC_OE,
	I => ADC_OE_OBUF);

--------------------------------------------------------------------------------
obuf_3 : OBUF
PORT MAP (
	O => AU_CSN,
	I => AU_CSN_OBUF);

--------------------------------------------------------------------------------
obuf_4 : OBUF
PORT MAP (
	O => USB_CS,
	I => USB_CS_OBUF);

--------------------------------------------------------------------------------
obuf_5 : OBUF
PORT MAP (
	O => NV_CS0,
	I => NV_CS0_OBUF);

--------------------------------------------------------------------------------
obuf_6 : OBUF
PORT MAP (
	O => NV_CS1,
	I => NV_CS1_OBUF);

--------------------------------------------------------------------------------
ibuf_7 : IBUF
PORT MAP (
	O => RS232_RD_IBUF,
	I => RS232_RD);

--------------------------------------------------------------------------------
obuf_8 : OBUF
PORT MAP (
	O => RS232_TD,
	I => RS232_TD_OBUF);

END ARCHITECTURE IMP;
