LIBRARY unisim;
USE unisim.vcomponents.ALL;

--------------------------------------------------------------------------------
-- bram_elaborate.vhd
--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;

-- synthesis translate_off
LIBRARY UNISIM;
USE UNISIM.VCOMPONENTS.ALL;
-- synthesis translate_on

ENTITY bram_elaborate IS
GENERIC (
	C_MEMSIZE : INTEGER := 8192;
	C_PORT_DWIDTH : INTEGER := 32;
	C_PORT_AWIDTH : INTEGER := 32;
	C_NUM_WE : INTEGER := 4;
	C_FAMILY : STRING := "spartan2e");
PORT (
	-- instance GLOBAL
	BRAM_Dout_B : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Rst_A : IN STD_LOGIC;
	BRAM_Addr_B : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Dout_A : IN STD_LOGIC_VECTOR(0 TO 31);
	BRAM_WEN_A : IN STD_LOGIC_VECTOR(0 TO 3);
	BRAM_EN_B : IN STD_LOGIC;
	BRAM_WEN_B : IN STD_LOGIC_VECTOR(0 TO 3);
	BRAM_Clk_B : IN STD_LOGIC;
	BRAM_Clk_A : IN STD_LOGIC;
	BRAM_Din_A : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Din_B : OUT STD_LOGIC_VECTOR(0 TO 31);
	BRAM_Rst_B : IN STD_LOGIC;
	BRAM_EN_A : IN STD_LOGIC;
	BRAM_Addr_A : IN STD_LOGIC_VECTOR(0 TO 31));
END bram_elaborate;

ARCHITECTURE IMP OF bram_elaborate IS

--------------------------------------------------------------------------------
COMPONENT RAMB4_S2_S2 IS
PORT (
	DIB : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
	WEB : IN STD_LOGIC;
	RSTB : IN STD_LOGIC;
	DOB : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
	ENB : IN STD_LOGIC;
	WEA : IN STD_LOGIC;
	ADDRB : IN STD_LOGIC_VECTOR(10 DOWNTO 0);
	DIA : IN STD_LOGIC_VECTOR(1 DOWNTO 0);
	ADDRA : IN STD_LOGIC_VECTOR(10 DOWNTO 0);
	RSTA : IN STD_LOGIC;
	CLKA : IN STD_LOGIC;
	CLKB : IN STD_LOGIC;
	DOA : OUT STD_LOGIC_VECTOR(1 DOWNTO 0);
	ENA : IN STD_LOGIC);
END COMPONENT;

--------------------------------------------------------------------------------
-- internal signals
--------------------------------------------------------------------------------

	SIGNAL dina : STD_LOGIC_VECTOR(31 DOWNTO 0);

	SIGNAL dinb : STD_LOGIC_VECTOR(31 DOWNTO 0);

	SIGNAL douta : STD_LOGIC_VECTOR(31 DOWNTO 0);

	SIGNAL doutb : STD_LOGIC_VECTOR(31 DOWNTO 0);

	SIGNAL net_gnd0 : STD_LOGIC;

BEGIN

--------------------------------------------------------------------------------
-- Power assignments
net_gnd0 <= '0';
--------------------------------------------------------------------------------
-- Constant assignments
--------------------------------------------------------------------------------
-- Top-level port assignments
dinb <= BRAM_Dout_B;
dina <= BRAM_Dout_A;
BRAM_Din_A <= douta;
BRAM_Din_B <= doutb;
--------------------------------------------------------------------------------
-- Lower-level assignments

--------------------------------------------------------------------------------
ramb4_s2_s2_0 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(31 DOWNTO 30),
	WEB => BRAM_WEN_B(0),
	RSTB => net_gnd0,
	DOB => doutb(31 DOWNTO 30),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(0),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(31 DOWNTO 30),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(31 DOWNTO 30),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_1 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(29 DOWNTO 28),
	WEB => BRAM_WEN_B(0),
	RSTB => net_gnd0,
	DOB => doutb(29 DOWNTO 28),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(0),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(29 DOWNTO 28),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(29 DOWNTO 28),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_2 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(27 DOWNTO 26),
	WEB => BRAM_WEN_B(0),
	RSTB => net_gnd0,
	DOB => doutb(27 DOWNTO 26),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(0),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(27 DOWNTO 26),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(27 DOWNTO 26),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_3 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(25 DOWNTO 24),
	WEB => BRAM_WEN_B(0),
	RSTB => net_gnd0,
	DOB => doutb(25 DOWNTO 24),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(0),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(25 DOWNTO 24),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(25 DOWNTO 24),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_4 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(23 DOWNTO 22),
	WEB => BRAM_WEN_B(1),
	RSTB => net_gnd0,
	DOB => doutb(23 DOWNTO 22),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(1),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(23 DOWNTO 22),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(23 DOWNTO 22),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_5 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(21 DOWNTO 20),
	WEB => BRAM_WEN_B(1),
	RSTB => net_gnd0,
	DOB => doutb(21 DOWNTO 20),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(1),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(21 DOWNTO 20),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(21 DOWNTO 20),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_6 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(19 DOWNTO 18),
	WEB => BRAM_WEN_B(1),
	RSTB => net_gnd0,
	DOB => doutb(19 DOWNTO 18),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(1),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(19 DOWNTO 18),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(19 DOWNTO 18),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_7 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(17 DOWNTO 16),
	WEB => BRAM_WEN_B(1),
	RSTB => net_gnd0,
	DOB => doutb(17 DOWNTO 16),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(1),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(17 DOWNTO 16),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(17 DOWNTO 16),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_8 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(15 DOWNTO 14),
	WEB => BRAM_WEN_B(2),
	RSTB => net_gnd0,
	DOB => doutb(15 DOWNTO 14),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(2),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(15 DOWNTO 14),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(15 DOWNTO 14),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_9 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(13 DOWNTO 12),
	WEB => BRAM_WEN_B(2),
	RSTB => net_gnd0,
	DOB => doutb(13 DOWNTO 12),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(2),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(13 DOWNTO 12),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(13 DOWNTO 12),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_10 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(11 DOWNTO 10),
	WEB => BRAM_WEN_B(2),
	RSTB => net_gnd0,
	DOB => doutb(11 DOWNTO 10),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(2),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(11 DOWNTO 10),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(11 DOWNTO 10),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_11 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(9 DOWNTO 8),
	WEB => BRAM_WEN_B(2),
	RSTB => net_gnd0,
	DOB => doutb(9 DOWNTO 8),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(2),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(9 DOWNTO 8),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(9 DOWNTO 8),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_12 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(7 DOWNTO 6),
	WEB => BRAM_WEN_B(3),
	RSTB => net_gnd0,
	DOB => doutb(7 DOWNTO 6),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(3),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(7 DOWNTO 6),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(7 DOWNTO 6),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_13 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(5 DOWNTO 4),
	WEB => BRAM_WEN_B(3),
	RSTB => net_gnd0,
	DOB => doutb(5 DOWNTO 4),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(3),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(5 DOWNTO 4),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(5 DOWNTO 4),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_14 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(3 DOWNTO 2),
	WEB => BRAM_WEN_B(3),
	RSTB => net_gnd0,
	DOB => doutb(3 DOWNTO 2),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(3),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(3 DOWNTO 2),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(3 DOWNTO 2),
	ENA => BRAM_EN_A);

--------------------------------------------------------------------------------
ramb4_s2_s2_15 : RAMB4_S2_S2
PORT MAP (
	DIB => dinb(1 DOWNTO 0),
	WEB => BRAM_WEN_B(3),
	RSTB => net_gnd0,
	DOB => doutb(1 DOWNTO 0),
	ENB => BRAM_EN_B,
	WEA => BRAM_WEN_A(3),
	ADDRB => BRAM_Addr_B(19 TO 29),
	DIA => dina(1 DOWNTO 0),
	ADDRA => BRAM_Addr_A(19 TO 29),
	RSTA => net_gnd0,
	CLKA => BRAM_Clk_A,
	CLKB => BRAM_Clk_B,
	DOA => douta(1 DOWNTO 0),
	ENA => BRAM_EN_A);

END ARCHITECTURE IMP;
